zerostash_files::tree

Struct Tree

pub struct Tree(/* private fields */);

Implementations

Source

impl Tree

pub fn insert_directory<'a>(&self, path: &'a str) -> Result<'a, ()>

Create a new directory at path, creating all entries in between

pub fn insert_file<'a>(&self, path: &'a str, file: Entry) -> Result<'a, ()>

Insert or overwrite an file at path, creating all entries in between

pub fn update_file<'a>(&self, path: &'a str, file: Entry) -> Result<'a, ()>

Updates an file at path

pub fn remove<'a>(&self, path: &'a str) -> Result<'a, ()>

Recursively remove a subtree the path

pub fn file<'a>(&self, path: &'a str) -> Result<'a, Option<Arc<Entry>>>

Return a file

pub fn node_by_ref(&self, noderef: &Digest) -> Option<Arc<Node>>

pub fn node_by_path<'a>(&self, path: &'a str) -> Result<'a, Option<Arc<Node>>>

Return a file system node

pub fn move_node<'a>( &self, old_path: &'a str, new_path: &'a str, ) -> Result<'a, ()>

Move the file from the old path to the new path in the tree

pub fn is_file<'a>(&self, path: &'a str) -> Result<'a, bool>

Returns if the path is a file

pub fn retain<F>(&self, f: F)
where F: FnMut(&str, &Node) -> bool,

pub fn iter_files(&self) -> TreeIterator<'_>

pub fn clear(&self) -> usize